#!/bin/bash
#
# Kleines Skript zum Korrigieren der PDF-Links, die sich _hinter_ dem
# Anhang eines mit LaTeX erzeugten PDF-Dokuments befinden.
#
# Das LaTeX-Makro \part definiert eigentlich _keine_
# Gliederungshierarchie. Trotzdem ist zu beobachten, dass wenn ein
# LaTeX-Dokument mit \part in unterschiedliche Abschnitte unterteilt
# wird, in der Hierarchie der PDF-Bookmarks am Ende des Dokuments z.B
# das Literaturverzeichnis und der Index dem letzten mit \part
# definierten Abschnitt zugeordnet werden (zu sehen im PDF-Viewer).
#
# Dieses Skript nutzt den Zeileneditor 'sed' zum Korrigieren der
# Gliederungstiefe von anzugebenen Abschnitten innerhalb der von
# LaTeX mit Hyperref erzeugten .out-Datei. Nach dem Aufruf dieses
# Skrips muss ein weiterer LaTeX-Durchlauf erfolgen. In der erzeugten
# PDF-Datei sind die Links korrgiert.
# 
# Autor: Wolfgang Runte
# Version: 2011-02-26

if [ "$1" == "" ] || [ "$2" == "" ]; then
  echo 'Resets the pdf bookmark of the given chapter in the pdf document hierarchy.'
  echo 'Usage:' "$0" 'latex-file chapter-name'
  echo 'latex-file without file extension .tex'
  echo 'chapter-name is the name of the chapter which pdf bookmark has to be corrected'
  exit 1
fi

# check if file exists
if ! [ -a "$1".out ]; then
  echo 'File not found:' "$1".out
  exit 2
fi
# check if file is a regular file
if ! [ -f "$1".out ]; then
  echo 'Not a regular file:' "$1".out
  exit 2
fi
# check if file is readable
if ! [ -r "$1".out ]; then
  echo 'File not readable:' "$1".out
  exit 2
fi
# check if file is writeable
if ! [ -w "$1".out ]; then
  echo 'File not writeable:' "$1".out
  exit 2
fi
# check if file size is zero
if ! [ -s "$1".out ]; then
  echo 'File size is zero:' "$1".out
  exit 2
fi

# sed command to remove information about hierarchy of the given chapter
# also remove potentially previously inserted preamble (see below)
sed "s/{$2}{.*}/{$2}{}/g;/^\\\let\\\WriteBookmarks\\\relax$/d" "$1".out > /tmp/"$1".out

# check if file size of generated file is zero
if ! [ -s /tmp/"$1".out ]; then
  rm /tmp/"$1".out
  echo 'Operation did not change anything in source file.'
  exit 3
fi

# add preamble so latex will not overwrite changes
echo '\let\WriteBookmarks\relax' > "$1".out
cat /tmp/"$1".out >> "$1".out
rm /tmp/"$1".out

